--- The functions to handle setting when a hireling mail is picked up.
--  Only registers when the mail's attachments have been taken.
--  @module TONHireling
--  @author Tirtow

local SECS_FOR_HIRELING_COOLDOWN = 24 * 60 * 60
local SECS_FOR_UPGRADED_COOLDOWN = SECS_FOR_HIRELING_COOLDOWN / 2
local HIRELING_SKILL_INDEX       = 3
local HIRELING_MAX_LEVEL         = 3
local HIRELINGS                  = {}
HIRELINGS[0] = {
  subject    = "Raw Blacksmith Materials",
  name       = "Blacksmithing Hireling",
  var_name   = "blacksmithing_hireling",
  line_index = 2
}
HIRELINGS[1] = {
  subject    = "Raw Clothier Materials",
  name       = "Clothing Hireling",
  var_name   = "clothing_hireling",
  line_index = 3
}
HIRELINGS[2] = {
  subject    = "Raw Enchanter Materials",
  name       = "Enchanting Hireling",
  var_name   = "enchanting_hireling",
  line_index = 4
}
HIRELINGS[4] = {
  subject    = "Raw Provisioner Materials",
  name       = "Provisioning Hireling",
  var_name   = "provisioning_hireling",
  line_index = 6
}
HIRELINGS[5] = {
  subject    = "Raw Woodworker Materials",
  name       = "Woodworking Hireling",
  var_name   = "woodworking_hireling",
  line_index = 7
}

--- Checks if received a hireling mail and updates the variable if so
--  @param mail_id  the ID of the mail received
function TON:CheckForHireling(mail_id)
  local _, _, subject = GetMailItemInfo(mail_id)
  local hireling = self:GetHireling(subject)
  if hireling ~= nil then
    local hireling = HIRELINGS[hireling]
    local cooldown = self:GetHirelingCooldown(hireling.line_index)
    local next_time = GetTimeStamp() + cooldown

    self.saved_variables.toons[self.toon_id][hireling.var_name] = next_time
    self:RequestPrioritySave()
    self:NotifyOfUpdate(hireling.name)
    self:PrintDebug("set hireling timer for " .. hireling.name .. " to " ..
                    tostring(next_time) .. " with cooldown " ..
                    tostring(cooldown))
  end
end

--- Gets the hireling based on the subject of the mail
--  @param subject  the subject of the mail
--  @return the index of the hireling in HIRELINGS or nil if not a hireling mail
function TON:GetHireling(subject)
  for index, table in pairs(HIRELINGS) do
    if subject == table.subject then
      return index
    end
  end

  return nil
end

--- Gets the cooldown in seconds for the given hireling.
--  The cooldown is 24 hours unless the hireling skill is maxed out in which
--  case it is 12 hours
--  @param line_index   the index of the skill line for the hireling
--  @return the cooldown in seconds
function TON:GetHirelingCooldown(line_index)
  local _, _, _, _, _, _, _, level = GetSkillAbilityInfo(SKILL_TYPE_TRADESKILL,
                                                         line_index,
                                                         HIRELING_SKILL_INDEX)
  self:PrintDebug("hireling level " .. tostring(level))
  if level == 3 then
    return SECS_FOR_UPGRADED_COOLDOWN
  else
    return SECS_FOR_HIRELING_COOLDOWN
  end
end
