--- The functions to handle setting when dremora plunder skulls are received.
--  Only registers when a skull is received so the addon must be enabled when
--  the skull is looted in order for the timer to be updated.
--  @module TONPlunderSkull
--  @author Tirtow

--- Number of seconds between plunder skulls
local SECS_FOR_SKULL_COOLDOWN = 20 * 60 * 60

--- Constants to identify plunder skulls
local SKULLS = {}
SKULLS[0] = {
  var_name    = "delve_skull",
  name        = "Delve Plunder Skull",
  coffer_name = "Dremora Plunder Skull, Delve"
}
SKULLS[1] = {
  var_name    = "trial_skull",
  name        = "Trial Plunder Skull",
  coffer_name = "Dremora Plunder Skull, Trial"
}
SKULLS[2] = {
  var_name    = "arena_skull",
  name        = "Arena Plunder Skull",
  coffer_name = "Dremora Plunder Skull, Arena"
}
SKULLS[3] = {
  var_name    = "insurgent_skull",
  name        = "Insurgent Plunder Skull",
  coffer_name = "Dremora Plunder Skull, Insurgent"
}
SKULLS[4] = {
  var_name    = "dungeon_skull",
  name        = "Dungeon Plunder Skull",
  coffer_name = "Dremora Plunder Skull, Dungeon"
}
SKULLS[5] = {
  var_name    = "sweeper_skull",
  name        = "Public & Sweeper Plunder Skull",
  coffer_name = "Dremora Plunder Skull, Public & Sweeper"
}
SKULLS[6] = {
  var_name    = "world_skull",
  name        = "World Plunder Skull",
  coffer_name = "Dremora Plunder Skull, World"
}

--- Checks if the user just received a gold plunder skull.
--  If received a plunder skull, updates that timer and notifies the user
--  @param item_link  the link for the item received
function TON:CheckIfGotPlunderSkull(toon_name, item_link)
  local name = ZO_StripGrammarMarkupFromCharacterName(GetUnitName("player"))
  local toon_name = ZO_StripGrammarMarkupFromCharacterName(toon_name)
  if toon_name == name then
    self:PrintDebug(tostring(item_link) .. " looted by player")
    local item_name = GetItemLinkName(item_link)
    for index, table in pairs(SKULLS) do
      if tostring(item_name) == table.coffer_name then
        self:PrintDebug("found skull " .. tostring(index))
        self:UpdatePlunderSkullTime(index)
      end
    end
  end
end

--- Handles updating the timer for a plunder skull.
--  @param index  the index in SKULLS of the plunder skull received
function TON:UpdatePlunderSkullTime(index)
  local skull = SKULLS[index]
  local next_time = GetTimeStamp() + SECS_FOR_SKULL_COOLDOWN
  self.saved_variables.toons[self.toon_id][skull.var_name] = next_time
  self:RequestPrioritySave()
  self:NotifyOfUpdate(skull.name)
  self:PrintDebug("set skull timer for " .. skull.name .. " to " ..
                  tostring(next_time))
end
