--- The functions to handle initializing the addon.
--  Saves the basic character info for all characters and saves the research
--  info for the current character. Deletes the saved variables entry for any
--  deleted characters.
--  @module TONStartup
--  @author Tirtow

--- Sets the alive boolean to false for each character.
--  This is done to enable checking which characters have been deleted
function TON:ClearAlive()
  for _, values in pairs(self.saved_variables.toons) do
    values.alive = false
  end
end

--- Dispalys the startup message
function TON:StartupMessage()
  d(string.format("|cFFFFFFTimers of Nirn|r |cDB0700v%s|r by " ..
                  "|c00DB36@Tirtow|r enabled.", self.version))
  d("Characters will be updated by the client on /reloadui or logout")
end

--- Saves the default character information for the character with the given
--  name using the provided information.
--  @param name       the name of the character. Should be formatted using
--                    zo_strformat
--  @param level      the level of the character
--  @param class      the class of the character
--  @param race       the race of the character
--  @param alliance   the alliance of the character
--  @param id         the ID of the character
function TON:SaveNewCharacter(name, level, class, race, alliance, id)
    self.saved_variables.toons[id] = {}
    self.saved_variables.toons[id].name                 = name
    self.saved_variables.toons[id].toon_class           = class
    self.saved_variables.toons[id].race                 = race
    self.saved_variables.toons[id].level                = level
    self.saved_variables.toons[id].alliance             = alliance
    self.saved_variables.toons[id].addon_id             = id
    self.saved_variables.toons[id].aetherian_archive    = DEFAULT_TIME
    self.saved_variables.toons[id].sanctum_ophidia      = DEFAULT_TIME
    self.saved_variables.toons[id].hel_ra_citadel       = DEFAULT_TIME
    self.saved_variables.toons[id].maw_of_lorkhaj       = DEFAULT_TIME
    self.saved_variables.toons[id].halls_of_fabrication = DEFAULT_TIME
    self.saved_variables.toons[id].asylum_sanctorium    = DEFAULT_TIME
    self.saved_variables.toons[id].horse                = DEFAULT_TIME
    self.saved_variables.toons[id].random               = DEFAULT_TIME
    self.saved_variables.toons[id].champion_points      = 0
    self.saved_variables.toons[id].seconds_played       = 0
    self.saved_variables.toons[id].updated_at           = GetTimeStamp()

    self:PrintDebug("saved default info for " .. name)
end

--- Saves the basic character info.
--  Saves name, class, race, alliance, and updates updated_at.
--  Also stores the index of this character for GetCharacterInfo()
function TON:SaveBasicInfo()
  local current_id = GetCurrentCharacterId()
  for i = 1, GetNumCharacters() do
    local name, _, level, class, race, alliance, id, _ = GetCharacterInfo(i)
    local name = zo_strformat(SI_UNIT_NAME, name)

    -- Save this character's info
    if id == current_id then
      self.saved_variables.toons[id].name       = name
      self.saved_variables.toons[id].toon_class = class
      self.saved_variables.toons[id].race       = race
      self.saved_variables.toons[id].alliance   = alliance
      self.saved_variables.toons[id].level      = level
      self.saved_variables.toons[id].updated_at = GetTimeStamp()
      self.saved_variables.toons[id].addon_id   = id

      if self.saved_variables.debug then
        d("TON: saved basic info:")
        d("name: "       .. self.saved_variables.toons[id].name)
        d("toon_class: " .. self.saved_variables.toons[id].toon_class)
        d("race: "       .. self.saved_variables.toons[id].race)
        d("alliance: "   .. self.saved_variables.toons[id].alliance)
        d("updated_at: " .. self.saved_variables.toons[id].updated_at)
      end
    elseif self.saved_variables.toons[id] == nil then
      self:SaveNewCharacter(name, level, class, race, alliance, id)
    end
	
	self.saved_variables.toons[id].alive = true
  end
end

--- Removes the table for any character which is not marked as alive.
--  TON#SaveBasicInfo() should be called before this to ensure alive
--  characters are correctly marked.
function TON:RemoveDeadCharacters()
  for i = 1, GetNumCharacters() do
    local _, _, _, _, _, _, id, _ = GetCharacterInfo(i)
    if not self.saved_variables.toons[id].alive then
      self.saved_variables.toons[id] = nil
    end
  end
end
