--- Various utility functions for Timers of Nirn.
--  @module TONUtils
--  @author Tirtow

-- Time constants
local SEC_PER_MIN  = 60
local SEC_PER_HOUR = SEC_PER_MIN * 60

--- Prints out the given debug string if the user has set to have debug output
--  shown
--  @param str  the string to print
function TON:PrintDebug(str)
  if self.saved_variables.debug then
    d("TON: " .. str)
  end
end

--- Gets the string to display for the time remaining until the LFG premium
--  reward is available again
--  @param timestamp  the timestamp of when the premium reward will be available
--  @return the string to display, whether or not reward is ready
function TON:GetWaitTime(timestamp)
  local diff = GetDiffBetweenTimeStamps(timestamp, GetTimeStamp())
  if diff <= 0 then
    return "Ready", true
  else
    local hours = math.floor(diff / SEC_PER_HOUR)
    local diff = diff - (hours * SEC_PER_HOUR)
    local mins = math.floor(diff / SEC_PER_MIN)
    local secs = diff - (mins * SEC_PER_MIN)

    return string.format("%d hours %d minutes and %d seconds",
                         hours, mins, secs),
           false
  end
end

--- Builds a table mapping the name of each character to the daily random
--  timestamp for that character.
--  @return the table of names and timestamps
function TON:BuildToonTable(var)
  local table = {}
  for id, info in pairs(self.saved_variables.toons) do
    table[info.name] = {}
    table[info.name].name = info.name
    table[info.name].time, table[info.name].ready = self:GetWaitTime(info[var])
  end

  return table
end

--- Sets given the toon name and time labels
--  @param toon_label   the label for the toon name
--  @param time_label   the label for the time
--  @param toon         table containing the fields name and time
function TON:SetGUIText(toon_label, time_label, toon)
  toon_label:SetText(toon.name)
  time_label:SetText(toon.time)
  if toon.ready then
    time_label:SetColor(0.019, 0.941, 0.070, 1)
  else
    time_label:SetColor(0.988, 0.290, 0.290, 1)
  end
end

--- Builds a table of the keys to the given table in sorted ascending order
--  @param t 	the table to get the sorted keys of
--  @return a sorted table of the keys to t
function TON:SortedKeys(t)
  local keys = {}
  for k in pairs(t) do
	table.insert(keys, k)
  end
  
  table.sort(keys)
  return keys
end
