--- Handles displaying the user interface to show the time remaining for the horse
--  feed timer for each character. Converts the timestamps into the time remaining
--  until the horse feed is available again.
--  @module TONHorseTimerUI_v1.0
--  @author Tirtow

--- Maximum number of toons
local MAX_TOONS = 15

--- Saves the coordinates for the top left corner of the UI so that when it is
--  opened again it is restored to the same position
function TON:SaveHorsePosition()
  self.saved_variables.ui_horse_left = TON_HORSE_UI_INTERFACE:GetLeft()
  self.saved_variables.ui_horse_top  = TON_HORSE_UI_INTERFACE:GetTop()
end

--- Builds a table of the labels used to display the horse times for each
--  character.
--  @return the table of labels
function TON:GetHorseLabels()
  local labels = {}
  labels[1]  = {toon_label = TON_HORSE_UI_INTERFACEToon1Name,
                time_label = TON_HORSE_UI_INTERFACEToon1Time}
  labels[2]  = {toon_label = TON_HORSE_UI_INTERFACEToon2Name,
                time_label = TON_HORSE_UI_INTERFACEToon2Time}
  labels[3]  = {toon_label = TON_HORSE_UI_INTERFACEToon3Name,
                time_label = TON_HORSE_UI_INTERFACEToon3Time}
  labels[4]  = {toon_label = TON_HORSE_UI_INTERFACEToon4Name,
                time_label = TON_HORSE_UI_INTERFACEToon4Time}
  labels[5]  = {toon_label = TON_HORSE_UI_INTERFACEToon5Name,	
                time_label = TON_HORSE_UI_INTERFACEToon5Time}
  labels[6]  = {toon_label = TON_HORSE_UI_INTERFACEToon6Name,
                time_label = TON_HORSE_UI_INTERFACEToon6Time}
  labels[7]  = {toon_label = TON_HORSE_UI_INTERFACEToon7Name,
                time_label = TON_HORSE_UI_INTERFACEToon7Time}
  labels[8]  = {toon_label = TON_HORSE_UI_INTERFACEToon8Name,
                time_label = TON_HORSE_UI_INTERFACEToon8Time}
  labels[9]  = {toon_label = TON_HORSE_UI_INTERFACEToon9Name,
                time_label = TON_HORSE_UI_INTERFACEToon9Time}
  labels[10] = {toon_label = TON_HORSE_UI_INTERFACEToon10Name,
                time_label = TON_HORSE_UI_INTERFACEToon10Time}
  labels[11] = {toon_label = TON_HORSE_UI_INTERFACEToon11Name,
                time_label = TON_HORSE_UI_INTERFACEToon11Time}
  labels[12] = {toon_label = TON_HORSE_UI_INTERFACEToon12Name,
                time_label = TON_HORSE_UI_INTERFACEToon12Time}
  labels[13] = {toon_label = TON_HORSE_UI_INTERFACEToon13Name,
                time_label = TON_HORSE_UI_INTERFACEToon13Time}
  labels[14] = {toon_label = TON_HORSE_UI_INTERFACEToon14Name,
                time_label = TON_HORSE_UI_INTERFACEToon14Time}
  labels[15] = {toon_label = TON_HORSE_UI_INTERFACEToon15Name,
                time_label = TON_HORSE_UI_INTERFACEToon15Time}

  return labels
end

--- Opens the UI.
--  Sets the name and remaining time for the horse feed for each toon. Hides
--  the unused labels.
function TON:OpenHorseUI()
  TON_HORSE_UI_INTERFACE:ClearAnchors()
  TON_HORSE_UI_INTERFACE:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT,
                                     self.saved_variables.ui_horse_left,
                                     self.saved_variables.ui_horse_top)

  -- Fill out the toon labels
  local toon_table = self:BuildToonTable("horse")
  local labels = self:GetHorseLabels()
  local count = 1
  local keys = self:SortedKeys(toon_table)
  for _, key in ipairs(keys) do
    self:SetGUIText(labels[count].toon_label, labels[count].time_label,
					toon_table[key])
	count = count + 1
  end

  -- Hide the unused labels
  for i = count, MAX_TOONS do
    labels[i].toon_label:SetHidden(true)
    labels[i].time_label:SetHidden(true)
  end

  -- Show UI
  self.horse_visible = true
  TON_HORSE_UI_INTERFACE:SetHidden(false)
end

--- Closes the UI
function TON:CloseHorseUI()
  self.horse_visible = false
  TON_HORSE_UI_INTERFACE:SetHidden(true)
end

-- Displays the UI if currently hidden or closes it if it is currently visible
function TON:ToggleHorseUI()
  if self.horse_visible then
    self:CloseHorseUI()
  else
    self:OpenHorseUI()
  end
end
